import React, { useEffect, useState, useRef, Suspense } from 'react';
import PropTypes from 'prop-types';
import { PLACEMENTS } from './config';
var BASE_CLASS = 'sui-AtomPopover';
var CLASS_INNER = BASE_CLASS + "-inner";
var PREFIX_PLACEMENT = BASE_CLASS + "-";
var DEFAULT_OFFSET = 'auto,4px';
var DEFAULT_TRIGGER = 'legacy';
var DEFAULT_DELAY = 0;
var Popover = React.lazy(function () {
  return import('reactstrap/lib/Popover');
});

function AtomPopover(_ref) {
  var children = _ref.children,
      closeIcon = _ref.closeIcon,
      content = _ref.content,
      id = _ref.id,
      _ref$onClose = _ref.onClose,
      onClose = _ref$onClose === void 0 ? function () {} : _ref$onClose,
      _ref$onOpen = _ref.onOpen,
      onOpen = _ref$onOpen === void 0 ? function () {} : _ref$onOpen,
      _ref$placement = _ref.placement,
      placement = _ref$placement === void 0 ? PLACEMENTS.BOTTOM : _ref$placement,
      showPopover = _ref.showPopover;
  var targetRef = useRef();

  var _useState = useState(showPopover),
      internalShowPopover = _useState[0],
      setInternalShowPopover = _useState[1];

  useEffect(function () {
    setInternalShowPopover(showPopover);
  }, [showPopover]);

  var extendChildren = function extendChildren() {
    var onClick = function onClick() {
      onOpen();
      setInternalShowPopover(true);
    };

    var ref = targetRef;
    var childrenOnly = React.Children.only(children);
    return React.Children.map(childrenOnly, function (child) {
      var attrs = {
        onClick: onClick
      };

      if (id) {
        attrs.id = id;
      } else {
        attrs.ref = ref;
      }

      return React.cloneElement(child, attrs);
    });
  };

  var handleToggle = function handleToggle() {
    setInternalShowPopover(!internalShowPopover);
    onClose();
  };

  return React.createElement("div", null, extendChildren(), internalShowPopover && React.createElement(Suspense, {
    fallback: React.createElement(React.Fragment, null)
  }, React.createElement(Popover, {
    className: BASE_CLASS,
    delay: DEFAULT_DELAY,
    innerClassName: CLASS_INNER,
    isOpen: internalShowPopover,
    offset: DEFAULT_OFFSET,
    placement: placement,
    placementPrefix: PREFIX_PLACEMENT,
    target: id || targetRef.current,
    toggle: handleToggle,
    trigger: DEFAULT_TRIGGER
  }, closeIcon && React.createElement("div", {
    className: BASE_CLASS + "-closeIcon",
    onClick: handleToggle
  }, closeIcon), content)));
}

AtomPopover.displayName = 'AtomPopover';
export { PLACEMENTS as atomPopoverPositions };
export default AtomPopover;